t9902: switch default branch name to main
Remove the penultimate use of "GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME= master" in our test suite. We have slowly been removing these ever since we started to switch the default branch name used in tests to "main". Signed-off-by: Phillip Wood <phillip.wood@dunelm.org.uk> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Phillip Wood committed
Sep 10, 2025 at 16:29 UTC
3d6e7ec4c138f027486d51e949573659d592ff9a
1 file changed
+3
-3
t/t9902-completion.sh
+3
-3
index 6650d33fba..964e1f1569 100755
--- a/t/t9902-completion.sh
+++ b/t/t9902-completion.sh
@@ -11,9 +11,9 @@ test_description='test bash completion'
# untraceable with such ancient Bash versions.
test_untraceable=UnfortunatelyYes
# Override environment and always use master for the default initial branch
# name for these tests, so that rev completion candidates are as expected.
-GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=master
+GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=main
export GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME
. ./lib-bash.sh
@@ -1453,7 +1453,7 @@ test_expect_success 'git bisect - start subcommand arguments before double-dash
HEAD Z
final Z
initial Z
- master Z
+ main Z
EOF
)
'
@@ -11,9 +11,9 @@ test_description='test bash completion'
# untraceable with such ancient Bash versions.
test_untraceable=UnfortunatelyYes
-# Override environment and always use master for the default initial branch
+# Override environment and always use main for the default initial branch
# name for these tests, so that rev completion candidates are as expected.